@extends ('layouts/template')

@section('content')

    <div class="p-3 mcp-theme-1">

        <div class="card">

            <div class="card-header px-3 py-2 d-flex align-items-center">
                <strong class="mr-4">
                    <i class="fas fa-user-injured"></i>
                    Billing Manager
                </strong>
                <select class="ml-auto max-width-300px form-control form-control-sm"
                        onchange="fastLoad('/practice-management/billing-manager/' + this.value, true, false, false)">
                    <option value="" {{ $proUid === '' ? 'selected' : '' }}>All Pros</option>
                    @foreach($allPros as $_pro)
                        <option value="{{$_pro->uid}}" {{ $proUid === $_pro->uid ? 'selected' : '' }}>{{$_pro->displayName()}}</option>
                    @endforeach
                </select>
            </div>
            <div class="card-body p-0">
                <table class="table table-sm table-condensed p-0 m-0">
                    <thead class="bg-light">
                    <tr>
                        <th class="border-0">Patient</th>
                        <th class="border-0">Note Eff. Date</th>


                        <th class="border-0">HCP</th>

                        <th class="border-0">Signed?</th>
                        <th class="border-0">Bills</th>

                        @if($performer->pro->pro_type == 'ADMIN')
                            <th class="border-0">Assessments</th>
                        @endif

                        @if($performer->pro->pro_type == 'ADMIN')
                            <th class="border-0">Claims</th>
                        @endif
                        <th class="px-3 border-0">Created</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach ($notes as $note)
                        <tr class="{{ $note->is_cancelled ? 'cancelled-item always-clickable' : '' }}">

                            <td class="">
                                <a href="/patients/view/{{ $note->client->uid }}/notes/view/{{ $note->uid }}">{{ $note->client->displayName() }}</a>
                            </td>
                            <td class="">
                                <a href="/patients/view/{{ $note->client->uid }}/notes/view/{{ $note->uid }}"
                                   class="font-weight-bold">
                                    {{ friendly_date_time($note->effective_dateest, false) }}
                                </a>
                                <span class="ml-1">{{ $note->is_cancelled ? '[cancelled]' : '' }}</span>
                            </td>
                            <td>{{$note->hcpPro->displayName()}}</td>
                            <td>{{$note->is_signed_by_hcp?'Yes':'No'}}</td>
                            <td>
                                <table class="table table-sm table-condensed table-stripe">
                                    <thead>
                                    <tr>
                                        <th>Service</th>
                                        <th># of units</th>
                                        <th>Signed?</th>
                                        <th>Cancelled?</th>
                                        <th>HCP ex. amount</th>
                                    </tr>
                                    </thead>
                                    <tbody>
                                    @foreach($note->bills as $bill)
                                        <tr>
                                            <td>{{$bill->code}}</td>
                                            @if($bill->code == 'Treatment Services')
                                                <td>{{floor($bill->number_of_units*60)}}m</td>
                                            @else
                                                <td>{{$bill->number_of_units}}</td>
                                            @endif
                                            <td>{{$bill->is_signed_by_hcp?'Yes':'No'}}</td>
                                            <td>{{ $bill->is_cancelled ?'Yes':'No'}}</td>
                                            <td>{{ $bill->hcp_expected_payment_amount }}</td>
                                        </tr>
                                    @endforeach
                                    </tbody>
                                </table>
                            </td>
                            @if($performer->pro->pro_type == 'ADMIN')
                                <td>
                                    <table class="table table-sm table-condensed table-stripe">
                                        <thead>
                                        <tr>
                                            <th>Code</th>
                                            <th>Description</th>
                                        </tr>
                                        </thead>
                                        <tbody>
                                        @foreach($note->reasons as $reason)
                                            <tr>
                                                <td>{{$reason->code}}</td>
                                                <td>{{$reason->description}}</td>
                                            </tr>
                                        @endforeach
                                        </tbody>
                                    </table>
                                </td>
                            @endif
                            @if($performer->pro->pro_type == 'ADMIN')
                                <td>
                                    <table class="table table-sm table-condensed table-stripe">
                                        <thead>
                                        <tr>
                                            <th>Identifier</th>
                                            <th>Submitted?</th>
                                        </tr>
                                        </thead>
                                        <tbody>
                                        @foreach($note->claims as $claim)
                                            <tr>
                                                <td>{{$claim->iid}}</td>
                                                <td>{{$claim->was_submitted?'Yes':'No'}}</td>
                                            </tr>
                                            <tr>
                                                <td colspan="2">
                                                    <strong>Claim Lines</strong>
                                                    <table class="table table-sm table-condensed table-striped">
                                                        <tr>
                                                            <th>CPT</th>
                                                            <th>ICDs</th>
                                                            <th>Date of Service</th>
                                                        </tr>
                                                        @foreach($claim->lines as $claimLine)
                                                            <tr>
                                                                <td>{{$claimLine->cpt}}</td>
                                                                <td>{{$claimLine->icds()}}</td>
                                                                <td>{{$claimLine->date_of_service}}</td>
                                                            </tr>
                                                        @endforeach
                                                    </table>
                                                </td>
                                            </tr>
                                        @endforeach
                                        </tbody>
                                    </table>
                                </td>
                            @endif
                            <td class="px-3">
                                {{ friendly_date_time($note->created_at, true) }}
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
                <div>
                    {{$notes->links()}}
                </div>
            </div>
        </div>
    </div>

@endsection
